@@ -531,7 +531,7 @@ class Painter (Sprite):
             color = self._linecolor
 
         # Render an image of the text
-        image = font_obj.render(str(text), True, self._linecolor)
+        image = font_obj.render(str(text), True, color)
         rect = image.get_rect()
 
         # Set the position of the text from the align parameter
