@@ -82,6 +82,8 @@ class Screen (pygame.sprite.LayeredUpdates):
         self._key_release_funcs = {}
         self._key_hold_funcs = {}
         self._click_funcs = [None for _ in range(5)]
+        self._release_funcs = [None for _ in range(5)]
+        self._mouse_move_func = None
 
         # The pygame surface that holds any drawing added to the screen
         self._canvas = pygame.Surface((width, height), pygame.SRCALPHA)
@@ -593,7 +595,7 @@ class Screen (pygame.sprite.LayeredUpdates):
                 raise ValueError("Invalid key!") from None
 
 
-    def on_click (self, func, button=1):
+    def on_click (self, func, button="left"):
         '''
         Add a function that will be called when the mouse clicks anywhere on
         this screen while it is active.
@@ -619,6 +621,54 @@ class Screen (pygame.sprite.LayeredUpdates):
             raise ValueError("Invalid button!")
 
 
+    def on_release (self, func, button="left"):
+        '''
+        Add a function that will be called when the mouse releases a button
+        anywhere on this screen while it is active.
+
+        You can provide the following arguments for the function `func`:
+         - `x` - will provide x-coordinate of the click
+         - `y` - will provide y-coordinate of the click
+         - `pos` - will provide a tuple of the coordinates (x and y) of the click
+         - `button` - will provide the name of the mouse button used to click
+        '''
+
+        # Convert the button string to a button number
+        if isinstance(button, str):
+            try:
+                button = pgputils.mouse_button_map[button]
+            except KeyError:
+                raise ValueError("Invalid button!")
+
+        # If a button is valid, add the function to the appropriate button
+        if 1 <= button <= 5:
+            self._release_funcs[button - 1] = func
+        else:
+            raise ValueError("Invalid button!")
+
+
+    def on_mouse_move (self, func):
+        '''
+        Add a function that will be called when the mouse is moved anywhere on
+        this screen while it is active.
+
+        You can provide the following arguments for the function `func`:
+         - `x` - will provide x-coordinate of the click
+         - `y` - will provide y-coordinate of the click
+         - `pos` - will provide a tuple of the coordinates (x and y) of the click
+        '''
+
+        # Convert the button string to a button number
+        if isinstance(button, str):
+            try:
+                button = pgputils.mouse_button_map[button]
+            except KeyError:
+                raise ValueError("Invalid button!")
+
+        # Add the function
+        self._mouse_move_func = func
+
+
     def on_timer (self, func, delay, repeat=False):
         '''
         Call a function after a given amount of time (in milliseconds).
